<?php
// Exit if accessed directly
if (!defined('ABSPATH')) exit;

/**
 *	After theme Setup Hook
 */
function holistic_coach_theme_setup()
{
    /**
     * Make child theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    load_child_theme_textdomain('holistic-coach', get_stylesheet_directory() . '/languages');
}
add_action('after_setup_theme', 'holistic_coach_theme_setup', 100);

function holistic_coach_customize_script()
{

    $my_theme = wp_get_theme();
    $version  = $my_theme['Version'];
    wp_enqueue_script('personal-coach-customize', get_stylesheet_directory_uri() . '/js/child-customize.js', array('jquery', 'customize-controls'), $version, true);
}
add_action('customize_controls_enqueue_scripts', 'holistic_coach_customize_script');

/**
 * Enqueue scripts and styles.
 */
function holistic_coach_scripts()
{
    $my_theme = wp_get_theme();
    $version  = $my_theme['Version'];

    wp_enqueue_style('blossom-coach', get_template_directory_uri() . '/style.css');
    wp_enqueue_style('holistic-coach', get_stylesheet_directory_uri() . '/style.css', array('blossom-coach'), $version);
    wp_enqueue_script('holistic-coach', get_stylesheet_directory_uri() . '/js/custom.js', array('jquery'), $version, true);

    $array = array(
        'rtl'       => is_rtl(),
    );

    wp_localize_script('holistic-coach', 'holistic_coach_data', $array);
}
add_action('wp_enqueue_scripts', 'holistic_coach_scripts', 10);

//Remove a function from the parent theme
function holistic_coach_remove_parent_filters()
{
    remove_action('customize_register', 'blossom_coach_customizer_theme_info');
    remove_action('customize_register', 'blossom_coach_customize_register_appearance');
    remove_action('wp_enqueue_scripts', 'blossom_coach_dynamic_css', 99);
}
add_action('init', 'holistic_coach_remove_parent_filters');

function holistic_coach_customize_register($wp_customize)
{

    /** Register customizer custom control */
    require_once get_stylesheet_directory() . '/custom-controls/radiobtn/class-radio-buttonset-control.php';

    $wp_customize->register_control_type('Holistic_Coach_Radio_Buttonset_Control');

    /** Wheel of Life */
    if (blossom_coach_is_wheel_of_life_activated()) $wp_customize->get_setting('wheeloflife_color')->default = '#f2f2f2';

    /* THEME INFO */
    $wp_customize->add_section('theme_info', array(
        'title'       => __('Demo & Documentation', 'holistic-coach'),
        'priority'    => 6,
    ));

    /** Important Links */
    $wp_customize->add_setting(
        'theme_info_theme',
        array(
            'default' => '',
            'sanitize_callback' => 'wp_kses_post',
        )
    );

    $theme_info = '<p>';
    $theme_info .= sprintf(__('Demo Link: %1$sClick here.%2$s', 'holistic-coach'),  '<a href="' . esc_url('https://blossomthemes.com/theme-demo/?theme=holistic-coach') . '" target="_blank">', '</a>');
    $theme_info .= '</p><p>';
    $theme_info .= sprintf(__('Documentation Link: %1$sClick here.%2$s', 'holistic-coach'),  '<a href="' . esc_url('https://docs.blossomthemes.com/holistic-coach/') . '" target="_blank">', '</a>');
    $theme_info .= '</p>';

    $wp_customize->add_control(
        new Blossom_Coach_Note_Control(
            $wp_customize,
            'theme_info_theme',
            array(
                'section'     => 'theme_info',
                'description' => $theme_info
            )
        )
    );

    $wp_customize->get_section('header_image')->panel                    = 'frontpage_settings';
    $wp_customize->get_section('header_image')->title                    = __('Banner Section', 'holistic-coach');
    $wp_customize->get_section('header_image')->priority                 = 10;
    $wp_customize->get_control('header_image')->active_callback          = 'blossom_coach_banner_ac';
    $wp_customize->get_control('header_video')->active_callback          = 'blossom_coach_banner_ac';
    $wp_customize->get_control('external_header_video')->active_callback = 'blossom_coach_banner_ac';
    $wp_customize->get_section('header_image')->description              = '';
    $wp_customize->get_setting('header_image')->transport                = 'refresh';
    $wp_customize->get_setting('header_video')->transport                = 'refresh';
    $wp_customize->get_setting('external_header_video')->transport       = 'refresh';

    /** Move Background Image section to appearance panel */
    $wp_customize->get_section('colors')->panel              = 'appearance_settings';
    $wp_customize->get_section('colors')->priority           = 10;
    $wp_customize->get_section('background_image')->panel    = 'appearance_settings';
    $wp_customize->get_section('background_image')->priority = 15;

    $wp_customize->add_panel(
        'appearance_settings',
        array(
            'title'       => __('Appearance Settings', 'holistic-coach'),
            'priority'    => 25,
            'capability'  => 'edit_theme_options',
            'description' => __('Change color and body background.', 'holistic-coach'),
        )
    );

    /** Typography */
    $wp_customize->add_section(
        'typography_settings',
        array(
            'title'    => __('Typography', 'holistic-coach'),
            'priority' => 20,
            'panel'    => 'appearance_settings',
        )
    );

    /** Primary Font */
    $wp_customize->add_setting(
        'primary_font',
        array(
            'default'            => 'Quicksand',
            'sanitize_callback' => 'blossom_coach_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Select_Control(
            $wp_customize,
            'primary_font',
            array(
                'label'          => __('Primary Font', 'holistic-coach'),
                'description' => __('Primary font of the site.', 'holistic-coach'),
                'section'     => 'typography_settings',
                'choices'     => blossom_coach_get_all_fonts(),
            )
        )
    );

    /** Secondary Font */
    $wp_customize->add_setting(
        'secondary_font',
        array(
            'default'            => 'David Libre',
            'sanitize_callback' => 'blossom_coach_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Select_Control(
            $wp_customize,
            'secondary_font',
            array(
                'label'          => __('Secondary Font', 'holistic-coach'),
                'description' => __('Secondary font of the site.', 'holistic-coach'),
                'section'     => 'typography_settings',
                'choices'     => blossom_coach_get_all_fonts(),
            )
        )
    );

    $wp_customize->add_setting(
        'ed_localgoogle_fonts',
        array(
            'default'           => false,
            'sanitize_callback' => 'blossom_coach_sanitize_checkbox',
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Toggle_Control(
            $wp_customize,
            'ed_localgoogle_fonts',
            array(
                'section'       => 'typography_settings',
                'label'         => __('Load Google Fonts Locally', 'holistic-coach'),
                'description'   => __('Enable to load google fonts from your own server instead from google\'s CDN. This solves privacy concerns with Google\'s CDN and their sometimes less-than-transparent policies.', 'holistic-coach')
            )
        )
    );

    $wp_customize->add_setting(
        'ed_preload_local_fonts',
        array(
            'default'           => false,
            'sanitize_callback' => 'blossom_coach_sanitize_checkbox',
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Toggle_Control(
            $wp_customize,
            'ed_preload_local_fonts',
            array(
                'section'       => 'typography_settings',
                'label'         => __('Preload Local Fonts', 'holistic-coach'),
                'description'   => __('Preloading Google fonts will speed up your website speed.', 'holistic-coach'),
                'active_callback' => 'blossom_coach_ed_localgoogle_fonts'
            )
        )
    );

    ob_start(); ?>

    <span style="margin-bottom: 5px;display: block;"><?php esc_html_e('Click the button to reset the local fonts cache', 'holistic-coach'); ?></span>

    <input type="button" class="button button-primary blossom-coach-flush-local-fonts-button" name="blossom-coach-flush-local-fonts-button" value="<?php esc_attr_e('Flush Local Font Files', 'holistic-coach'); ?>" />
    <?php
    $holistic_coach_flush_button = ob_get_clean();

    $wp_customize->add_setting(
        'ed_flush_local_fonts',
        array(
            'sanitize_callback' => 'wp_kses_post',
        )
    );

    $wp_customize->add_control(
        'ed_flush_local_fonts',
        array(
            'label'         => __('Flush Local Fonts Cache', 'holistic-coach'),
            'section'       => 'typography_settings',
            'description'   => $holistic_coach_flush_button,
            'type'          => 'hidden',
            'active_callback' => 'blossom_coach_ed_localgoogle_fonts'
        )
    );

    /** Primary Color*/
    $wp_customize->add_setting(
        'primary_color',
        array(
            'default'           => '#ffc2b7',
            'sanitize_callback' => 'sanitize_hex_color',
            'transport'         => 'postMessage',
        )
    );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'primary_color',
            array(
                'label'       => __('Primary Color', 'holistic-coach'),
                'description' => __('Primary color of the theme.', 'holistic-coach'),
                'section'     => 'colors',
                'priority'    => 5,
            )
        )
    );

    /** Secondary Color*/
    $wp_customize->add_setting(
        'secondary_color',
        array(
            'default'           => '#2d4675',
            'sanitize_callback' => 'sanitize_hex_color',
            'transport'         => 'postMessage',
        )
    );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'secondary_color',
            array(
                'label'       => __('Secondary Color', 'holistic-coach'),
                'description' => __('Secondary color of the theme.', 'holistic-coach'),
                'section'     => 'colors',
                'priority'    => 5,
            )
        )
    );

    /** Header Layout Settings */
    $wp_customize->add_section(
        'header_layout_settings',
        array(
            'title'    => __('Header Layout', 'holistic-coach'),
            'priority' => 10,
            'panel'    => 'layout_settings',
        )
    );

    /** Page Sidebar layout */
    $wp_customize->add_setting(
        'header_layout',
        array(
            'default'           => 'seven',
            'sanitize_callback' => 'blossom_coach_sanitize_radio'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Radio_Image_Control(
            $wp_customize,
            'header_layout',
            array(
                'section'      => 'header_layout_settings',
                'label'          => __('Header Layout', 'holistic-coach'),
                'description' => __('Choose the layout of the header for your site.', 'holistic-coach'),
                'choices'      => array(
                    'one'   => get_stylesheet_directory_uri() . '/images/one.png',
                    'seven' => get_stylesheet_directory_uri() . '/images/seven.png',
                )
            )
        )
    );

    $wp_customize->add_setting(
        'header_settings_text',
        array(
            'default' => '',
            'sanitize_callback' => 'wp_kses_post'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Note_Control(
            $wp_customize,
            'header_settings_text',
            array(
                'section'       => 'header_layout_settings',
                'description'   => sprintf(__('%1$sClick here%2$s to configure header layout settings', 'holistic-coach'), '<span class="text-inner-link header_settings_text">', '</span>'),
            )
        )
    );

    // Getting Started Button Label
    $wp_customize->add_setting(
        'header_getting_started_button',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage'
        )
    );

    $wp_customize->add_control(
        'header_getting_started_button',
        array(
            'label'           => __('Header Getting Started Button', 'holistic-coach'),
            'section'         => 'header_settings',
            'type'            => 'text',
            'active_callback' => 'holistic_coach_get_contact_ac',
        )
    );

    $wp_customize->selective_refresh->add_partial('header_getting_started_button', array(
        'selector'        => '.site-header .button-wrap .btn-1',
        'render_callback' => 'holistic_coach_get_getting_started_button',
    ));

    $wp_customize->add_setting(
        'header_getting_started_url',
        array(
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control(
        'header_getting_started_url',
        array(
            'label'           => __('Header Getting Started Link', 'holistic-coach'),
            'section'         => 'header_settings',
            'type'            => 'url',
            'active_callback' => 'holistic_coach_get_contact_ac',
        )
    );

    /** Open header getting started url  in a new tab */
    $wp_customize->add_setting(
        'header_getting_started_url_new_tab',
        array(
            'default'           => true,
            'sanitize_callback' => 'blossom_coach_sanitize_checkbox'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Toggle_Control(
            $wp_customize,
            'header_getting_started_url_new_tab',
            array(
                'section'         => 'header_settings',
                'label'           => __('Open in new tab', 'holistic-coach'),
                'description'     => __('Enable to open the link in a new tab.', 'holistic-coach'),
                'active_callback' => 'holistic_coach_get_contact_ac',
            )
        )
    );

    $wp_customize->add_setting(
        'header_layout_text',
        array(
            'default' => '',
            'sanitize_callback' => 'wp_kses_post'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Note_Control(
            $wp_customize,
            'header_layout_text',
            array(
                'section' => 'header_settings',
                'description' => sprintf(__('%1$sClick here%2$s to configure header layout settings', 'holistic-coach'), '<span class="text-inner-link header_layout_text">', '</span>'),
            )
        )
    );

    /** Banner Options */
    $wp_customize->add_setting(
        'ed_banner_section',
        array(
            'default'            => 'static_banner',
            'sanitize_callback' => 'blossom_coach_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Select_Control(
            $wp_customize,
            'ed_banner_section',
            array(
                'label'          => __('Banner Options', 'holistic-coach'),
                'description' => __('Choose banner as static image/video or as a slider.', 'holistic-coach'),
                'section'     => 'header_image',
                'choices'     => array(
                    'no_banner'        => __('Disable Banner Section', 'holistic-coach'),
                    'static_nl_banner' => __('Static/Video Newsletter Banner', 'holistic-coach'),
                    'slider_banner'    => __('Banner as Slider', 'holistic-coach'),
                    'static_banner'    => __('Static/Video CTA Banner', 'holistic-coach')
                ),
                'priority' => 5
            )
        )
    );

    /** Sub Title */
    $wp_customize->add_setting(
        'banner_text',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage'
        )
    );

    $wp_customize->add_control(
        'banner_text',
        array(
            'label'           => __('Subtitle', 'holistic-coach'),
            'section'         => 'header_image',
            'type'            => 'text',
            'active_callback' => 'blossom_coach_banner_ac'
        )
    );

    $wp_customize->selective_refresh->add_partial('banner_text', array(
        'selector'        => '.site-banner .banner-caption .banner-wrap h5.subtitle',
        'render_callback' => 'holistic_coach_get_banner_sub_title',
    ));

    /** Title */
    $wp_customize->add_setting(
        'banner_title',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage',
        )
    );

    $wp_customize->add_control(
        'banner_title',
        array(
            'label'           => __('Title', 'holistic-coach'),
            'section'         => 'header_image',
            'type'            => 'text',
            'active_callback' => 'blossom_coach_banner_ac',
        )
    );

    $wp_customize->selective_refresh->add_partial('banner_title', array(
        'selector'        => '.site-banner .banner-caption .banner-wrap .banner-title',
        'render_callback' => 'holistic_coach_get_banner_title',
    ));

    /** Content */
    $wp_customize->add_setting(
        'banner_subtitle',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses_post',
            'transport'         => 'postMessage',
        )
    );

    $wp_customize->add_control(
        'banner_subtitle',
        array(
            'label'           => __('Description', 'holistic-coach'),
            'section'         => 'header_image',
            'type'            => 'textarea',
            'active_callback' => 'blossom_coach_banner_ac',
        )
    );

    $wp_customize->selective_refresh->add_partial('banner_subtitle', array(
        'selector'        => '.site-banner .banner-caption .banner-wrap .b-content',
        'render_callback' => 'holistic_coach_get_banner_content',
    ));

    /** Banner Label */
    $wp_customize->add_setting(
        'banner_label',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage',
        )
    );

    $wp_customize->add_control(
        'banner_label',
        array(
            'label'           => __('Banner Label', 'holistic-coach'),
            'section'         => 'header_image',
            'type'            => 'text',
            'active_callback' => 'blossom_coach_banner_ac',
        )
    );

    $wp_customize->selective_refresh->add_partial('banner_label', array(
        'selector'        => '.site-banner .banner-caption .banner-wrap .banner-link',
        'render_callback' => 'holistic_coach_get_banner_label',
    ));

    /** Banner Link */
    $wp_customize->add_setting(
        'banner_link',
        array(
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control(
        'banner_link',
        array(
            'label'           => __('Banner Link', 'holistic-coach'),
            'section'         => 'header_image',
            'type'            => 'text',
            'active_callback' => 'blossom_coach_banner_ac',
        )
    );

    $wp_customize->add_setting(
        'banner_caption_layout',
        array(
            'default'           => 'left',
            'sanitize_callback' => 'holistic_coach_sanitize_radio'
        )
    );

    $wp_customize->add_control(
        new Holistic_Coach_Radio_Buttonset_Control(
            $wp_customize,
            'banner_caption_layout',
            array(
                'section'     => 'header_image',
                'label'       => __('Banner Image Alignment', 'holistic-coach'),
                'description' => __('Choose alignment for banner image.', 'holistic-coach'),
                'choices'     => array(
                    'left'      => __('Left', 'holistic-coach'),
                    'right'     => __('Right', 'holistic-coach'),
                ),
                'active_callback' => 'blossom_coach_banner_ac'
            )
        )
    );

    $wp_customize->add_setting(
        'banner_link_new_tab',
        array(
            'default'           => false,
            'sanitize_callback' => 'blossom_coach_sanitize_checkbox',
        )
    );

    $wp_customize->add_control(
        new Blossom_Coach_Toggle_Control(
            $wp_customize,
            'banner_link_new_tab',
            array(
                'section'     => 'header_image',
                'label'       => __('Open Banner link in new tab', 'holistic-coach'),
                'description' => __('Enable to open  banner link in new tab.', 'holistic-coach'),
                'active_callback' => 'blossom_coach_banner_ac'
            )
        )
    );
}
add_action('customize_register', 'holistic_coach_customize_register', 40);

/**
 * Active Callback for Header Getting Started
 */
function holistic_coach_get_contact_ac($control)
{
    $header_layout = $control->manager->get_setting('header_layout')->value();
    $control_id    = $control->id;

    if ($control_id == 'header_getting_started_button' && $header_layout == 'seven') return true;
    if ($control_id == 'header_getting_started_url' && $header_layout == 'seven') return true;
    if ($control_id == 'header_getting_started_url_new_tab' && $header_layout == 'seven') return true;

    return false;
}

/**
 * Active Callback for Banner Slider
 */
function blossom_coach_banner_ac($control)
{
    $banner      = $control->manager->get_setting('ed_banner_section')->value();
    $slider_type = $control->manager->get_setting('slider_type')->value();
    $control_id  = $control->id;

    if ($control_id == 'header_image' && ($banner == 'static_nl_banner' || $banner == 'static_banner')) return true;
    if ($control_id == 'header_video' && ($banner == 'static_nl_banner' || $banner == 'static_banner')) return true;
    if ($control_id == 'external_header_video' && ($banner == 'static_nl_banner' || $banner == 'static_banner')) return true;
    if ($control_id == 'header_image_mobile' && ($banner == 'static_nl_banner' || $banner == 'static_banner')) return true;
    if ($control_id == 'banner_newsletter' && $banner == 'static_nl_banner') return true;
    if ($control_id == 'banner_nl_note' && $banner == 'static_nl_banner') return true;

    if ($control_id == 'slider_type' && $banner == 'slider_banner') return true;
    if ($control_id == 'slider_animation' && $banner == 'slider_banner') return true;
    if ($control_id == 'slider_cat' && $banner == 'slider_banner' && $slider_type == 'cat') return true;
    if ($control_id == 'no_of_slides' && $banner == 'slider_banner' && $slider_type == 'latest_posts') return true;
    if ($control_id == 'banner_title' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_subtitle' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_text' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_label' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_link' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_caption_layout' && $banner == 'static_banner') return true;
    if ($control_id == 'banner_link_new_tab' && $banner == 'static_banner') return true;

    return false;
}

function holistic_coach_sanitize_radio($input, $setting)
{
    // Ensure input is a slug.
    $input = sanitize_key($input);
    // Get list of choices from the control associated with the setting.
    $choices = $setting->manager->get_control($setting->id)->choices;
    // If the input is a valid key, return it; otherwise, return the default.
    return (array_key_exists($input, $choices) ? $input : $setting->default);
}

if (!function_exists('holistic_coach_get_getting_started_button')) :
    /**
     * Header Getting Started Button
     */
    function holistic_coach_get_getting_started_button()
    {
        return esc_html(get_theme_mod('header_getting_started_button'));
    }
endif;

if (!function_exists('holistic_coach_get_banner_sub_title')) :
    /**
     * Get Banner Sub Title
     */
    function holistic_coach_get_banner_sub_title()
    {
        return esc_html(get_theme_mod('banner_text'));
    }
endif;

if (!function_exists('holistic_coach_get_banner_title')) :
    /**
     * Get Banner Title
     */
    function holistic_coach_get_banner_title()
    {
        return esc_html(get_theme_mod('banner_title'));
    }
endif;

if (!function_exists('holistic_coach_get_banner_content')) :
    /**
     * Get Banner Content
     */
    function holistic_coach_get_banner_content()
    {
        return wpautop(wp_kses_post(get_theme_mod('banner_subtitle')));
    }
endif;

if (!function_exists('holistic_coach_get_banner_label')) :
    /**
     * Get Banner Label
     */
    function holistic_coach_get_banner_label()
    {
        return esc_html(get_theme_mod('banner_label'));
    }
endif;

/**
 * Getting Started Button 
 */
function blossom_coach_getting_started_button()
{
    $header_getting_started_button  = get_theme_mod('header_getting_started_button');
    $header_getting_started_url     = get_theme_mod('header_getting_started_url');
    $new_tab                        = get_theme_mod('header_getting_started_url_new_tab', true);
    $target                         = $new_tab ? 'target=_blank' : '';
    if ($header_getting_started_button && $header_getting_started_url) : ?>
        <div class="button-wrap">
            <a href="<?php echo esc_url($header_getting_started_url); ?>" class="btn-cta btn-1" <?php echo esc_attr($target); ?>><?php echo esc_html($header_getting_started_button); ?></a>
        </div>
    <?php
    endif;
}

/**
 * Function for mobile navigation menu
 */
function holistic_coach_mobile_menu()
{
    $ed_cart   = get_theme_mod('ed_shopping_cart', true);
    $ed_search = get_theme_mod('ed_header_search', true);
    $phone     = get_theme_mod('phone');
    $email     = get_theme_mod('email');
    ?>
    <div class="mobile-menu-wrapper">
        <div class="main-header">
            <div class="wrapper">
                <?php blossom_coach_site_branding(); ?>
                <button type="button" class="toggle-button" data-toggle-target=".menu-modal" data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".close-nav-toggle">
                    <span class="toggle-bar"></span>
                    <span class="toggle-bar"></span>
                    <span class="toggle-bar"></span>
                </button>
            </div><!-- .main-header -->
        </div>
        <div class="nav-slide-wrapper secondary-menu-list menu-modal cover-modal" data-modal-target-string=".menu-modal">
            <div class="header-t">
                <button class=" close toggle-button close-nav-toggle" data-toggle-target=".menu-modal" data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".menu-modal"><span></span></button>
                <div class="wrapper mobile-menu" aria-label="<?php esc_attr_e('Mobile', 'holistic-coach'); ?>">
                    <?php if (blossom_coach_social_links(false) || $ed_search) {
                        echo '<div class="top-right">';
                        if (blossom_coach_social_links(false)) {
                            echo '<div class="header-social">';
                            blossom_coach_social_links();
                            echo '</div><!-- .header-social -->';
                        }
                        if ($ed_search || (blossom_coach_is_woocommerce_activated() && $ed_cart)) {
                            if ($ed_search) blossom_coach_header_search();
                            if (blossom_coach_is_woocommerce_activated() && $ed_cart) blossom_coach_wc_cart_count();
                        }
                        echo '</div><!-- .top-right -->';
                    } ?>
                    <div class="menu-wrap">
                        <nav id="site-navigation" class="main-navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">

                            <?php
                            wp_nav_menu(array(
                                'theme_location' => 'primary',
                                'menu_id'        => 'primary-menu',
                                'menu_class'     => 'menu',
                                'fallback_cb'    => 'blossom_coach_primary_menu_fallback',
                            ));
                            ?>


                        </nav><!-- #site-navigation -->
                    </div>
                    <div class="wrap-right">
                        <?php blossom_coach_header_phone_email($phone, $email);
                        blossom_coach_getting_started_button(); ?>
                    </div>
                </div><!-- .wrapper -->

            </div><!-- .header-t -->
        </div>

    </div>
<?php }

/**
 * Header Start
 */
function blossom_coach_header()
{
    $ed_cart       = get_theme_mod('ed_shopping_cart', true);
    $ed_search     = get_theme_mod('ed_header_search', false);
    $phone         = get_theme_mod('phone');
    $email         = get_theme_mod('email');
    $header_layout = get_theme_mod('header_layout', 'seven');
?>
    <header id="masthead" class="site-header <?php if ($header_layout == 'seven') echo 'header-lay7'; ?>" itemscope itemtype="http://schema.org/WPHeader">
        <?php
        if ($header_layout == 'one') {
            if ($phone || $email || blossom_coach_social_links(false) || $ed_search) { ?>
                <div class="header-t">
                    <div class="wrapper">
                        <?php
                        blossom_coach_header_phone_email($phone, $email);

                        if (blossom_coach_social_links(false) || $ed_search) {
                            echo '<div class="top-right">';
                            if (blossom_coach_social_links(false)) {
                                echo '<div class="header-social">';
                                blossom_coach_social_links();
                                echo '</div><!-- .header-social -->';
                            }

                            if ($ed_search) blossom_coach_header_search();
                            echo '</div><!-- .top-right -->';
                        }
                        ?>
                    </div><!-- .wrapper -->
                </div><!-- .header-t -->
            <?php } ?>

            <div class="main-header">
                <div class="wrapper">
                    <?php blossom_coach_site_branding(); ?>
                    <div class="menu-wrap">
                        <?php
                        blossom_coach_primary_nagivation();
                        if (blossom_coach_is_woocommerce_activated() && $ed_cart) blossom_coach_wc_cart_count(); ?>
                    </div><!-- .menu-wrap -->
                </div><!-- .wrapper -->
            </div><!-- .main-header -->
        <?php } else {
        ?>
            <div class="main-header desktop">
                <div class="wrapper">
                    <?php blossom_coach_site_branding(); ?>
                    <div class="wrap-right">
                        <?php if ($phone || $email) blossom_coach_header_phone_email($phone, $email);
                        blossom_coach_getting_started_button(); ?>
                    </div>
                </div>
            </div><!-- .main-header -->
            <div class="header-t desktop">
                <div class="wrapper">
                    <div class="menu-wrap">
                        <?php blossom_coach_primary_nagivation(); ?>
                    </div>
                    <?php if (blossom_coach_social_links(false) || $ed_search) {
                        echo '<div class="top-right">';
                        if (blossom_coach_social_links(false)) {
                            echo '<div class="header-social">';
                            blossom_coach_social_links();
                            echo '</div><!-- .header-social -->';
                        }
                        if ($ed_search || (blossom_coach_is_woocommerce_activated() && $ed_cart)) {
                            if ($ed_search) blossom_coach_header_search();
                            if (blossom_coach_is_woocommerce_activated() && $ed_cart) blossom_coach_wc_cart_count();
                        }
                        echo '</div><!-- .top-right -->';
                    } ?>
                </div><!-- .wrapper -->
            </div><!-- .header-t -->
        <?php
            holistic_coach_mobile_menu();
        } ?>
    </header><!-- .site-header -->
<?php
}

/**
 * Returns Home Sections 
 */
function blossom_coach_get_home_sections()
{
    $ed_banner = get_theme_mod('ed_banner_section', 'static_banner');
    $sections = array(
        'client'        => array('sidebar' => 'client'),
        'about'         => array('sidebar' => 'about'),
        'cta'           => array('sidebar' => 'cta'),
        'testimonial'   => array('sidebar' => 'testimonial'),
        'service'       => array('sidebar' => 'service'),
        'wheeloflife'   => array('wsection' => 'wheeloflife'),
        'blog'          => array('bsection' => 'blog'),
        'simple-cta'    => array('sidebar' => 'simple-cta'),
        'contact'       => array('sidebar' => 'contact'),
    );

    $enabled_section = array();

    if ($ed_banner == 'static_nl_banner' || $ed_banner == 'slider_banner' || $ed_banner == 'static_banner') array_push($enabled_section, 'banner');

    foreach ($sections as $k => $v) {
        if (array_key_exists('sidebar', $v)) {
            if (is_active_sidebar($v['sidebar'])) array_push($enabled_section, $v['sidebar']);
        } else {
            if (array_key_exists('bsection', $v) && get_theme_mod('ed_blog_section', true)) array_push($enabled_section, $v['bsection']);
            if (array_key_exists('wsection', $v) && get_theme_mod('ed_wheeloflife_section', false)) array_push($enabled_section, $v['wsection']);
        }
    }

    return apply_filters('blossom_coach_home_sections', $enabled_section);
}

/**
 * Footer Bottom
 */
function blossom_coach_footer_bottom()
{ ?>
    <div class="bottom-footer">
        <div class="wrapper">
            <div class="copyright">
                <?php
                blossom_coach_get_footer_copyright();
                echo esc_html__(' Holistic Coach | Developed By ', 'holistic-coach');
                echo '<a href="' . esc_url('https://blossomthemes.com/') . '" rel="nofollow" target="_blank">' . esc_html__('Blossom Themes', 'holistic-coach') . '</a>.';
                printf(esc_html__(' Powered by %s', 'holistic-coach'), '<a href="' . esc_url(__('https://wordpress.org/', 'holistic-coach')) . '" target="_blank">WordPress</a>.');
                if (function_exists('the_privacy_policy_link')) {
                    the_privacy_policy_link();
                }
                ?>
            </div>
        </div><!-- .wrapper -->
    </div><!-- .bottom-footer -->
<?php

}

function blossom_coach_fonts_url()
{
    $fonts_url = '';

    $primary_font       = get_theme_mod('primary_font', 'Quicksand');
    $ig_primary_font    = blossom_coach_is_google_font($primary_font);
    $secondary_font     = get_theme_mod('secondary_font', 'David Libre');
    $ig_secondary_font  = blossom_coach_is_google_font($secondary_font);
    $site_title_font    = get_theme_mod('site_title_font', array('font-family' => 'Nunito', 'variant' => '700'));
    $ig_site_title_font = blossom_coach_is_google_font($site_title_font['font-family']);

    /* Translators: If there are characters in your language that are not
    * supported by respective fonts, translate this to 'off'. Do not translate
    * into your own language.
    */
    $primary    = _x('on', 'Primary Font: on or off', 'holistic-coach');
    $secondary  = _x('on', 'Secondary Font: on or off', 'holistic-coach');
    $site_title = _x('on', 'Site Title Font: on or off', 'holistic-coach');

    if ('off' !== $primary || 'off' !== $secondary || 'off' !== $site_title) {

        $font_families = array();

        if ('off' !== $primary && $ig_primary_font) {
            $primary_variant = blossom_coach_check_varient($primary_font, 'regular', true);
            if ($primary_variant) {
                $primary_var = ':' . $primary_variant;
            } else {
                $primary_var = '';
            }
            $font_families[] = $primary_font . $primary_var;
        }

        if ('off' !== $secondary && $ig_secondary_font) {
            $secondary_variant = blossom_coach_check_varient($secondary_font, 'regular', true);
            if ($secondary_variant) {
                $secondary_var = ':' . $secondary_variant;
            } else {
                $secondary_var = '';
            }
            $font_families[] = $secondary_font . $secondary_var;
        }

        if ('off' !== $site_title && $ig_site_title_font) {

            if (!empty($site_title_font['variant'])) {
                $site_title_var = ':' . blossom_coach_check_varient($site_title_font['font-family'], $site_title_font['variant']);
            } else {
                $site_title_var = '';
            }
            $font_families[] = $site_title_font['font-family'] . $site_title_var;
        }

        $font_families = array_diff(array_unique($font_families), array(''));

        $query_args = array(
            'family' => urlencode(implode('|', $font_families)),
        );

        $fonts_url = add_query_arg($query_args, 'https://fonts.googleapis.com/css');
    }

    if (get_theme_mod('ed_localgoogle_fonts', false)) {
        $fonts_url = blossom_coach_get_webfont_url(add_query_arg($query_args, 'https://fonts.googleapis.com/css'));
    }

    return esc_url_raw($fonts_url);
}

/**
 * convert hex to rgb
 * @link http://bavotasan.com/2011/convert-hex-color-to-rgb-using-php/
 */
function blossom_coach_hex2rgb($hex)
{
    $hex = str_replace("#", "", $hex);

    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    $rgb = array($r, $g, $b);
    //return implode(",", $rgb); // returns the rgb values separated by commas
    return $rgb; // returns an array with the rgb values
}

function holistic_coach_dynamic_css()
{

    $primary_font         = get_theme_mod('primary_font', 'Quicksand');
    $primary_fonts        = blossom_coach_get_fonts($primary_font, 'regular');
    $secondary_font       = get_theme_mod('secondary_font', 'David Libre');
    $secondary_fonts      = blossom_coach_get_fonts($secondary_font, 'regular');

    $site_title_font      = get_theme_mod('site_title_font', array('font-family' => 'Nunito', 'variant' => '700'));
    $site_title_fonts     = blossom_coach_get_fonts($site_title_font['font-family'], $site_title_font['variant']);
    $site_title_font_size = get_theme_mod('site_title_font_size', 45);

    $primary_color     = get_theme_mod('primary_color', '#ffc2b7');
    $secondary_color   = get_theme_mod('secondary_color', '#2d4675');
    $logo_width        = get_theme_mod('logo_width', 60);
    $wheeloflife_color = get_theme_mod('wheeloflife_color', '#f2f2f2');
    $rgb               = blossom_coach_hex2rgb(blossom_coach_sanitize_hex_color($primary_color));
    $rgb_secondary     = blossom_coach_hex2rgb(blossom_coach_sanitize_hex_color($secondary_color));

    $custom_css = '';
    $custom_css .= '
    
    :root {
        --primary-font: ' . esc_html($primary_fonts['font']) . ';
        --secondary-font: ' . esc_html($secondary_fonts['font']) . ';
        --primary-color: ' . blossom_coach_sanitize_hex_color($primary_color) . ';
        --primary-color-rgb: ' . sprintf('%1$s, %2$s, %3$s', $rgb[0], $rgb[1], $rgb[2]) .';
        --secondary-color: ' .  blossom_coach_sanitize_hex_color($secondary_color) . ';
        --secondary-color-rgb: ' . sprintf('%1$s, %2$s, %3$s', $rgb_secondary[0], $rgb_secondary[1], $rgb_secondary[2]) .';
    }
    
    .site-title, 
    .site-title-wrap .site-title{
        font-size   : ' . absint($site_title_font_size) . 'px;
        font-family : ' . esc_html($site_title_fonts['font']) . ';
        font-weight : ' . esc_html($site_title_fonts['weight']) . ';
        font-style  : ' . esc_html($site_title_fonts['style']) . ';
    }

    section#wheeloflife_section {
        background-color: ' . blossom_coach_sanitize_hex_color($wheeloflife_color) . ';
    }

    .custom-logo-link img{
        width    : ' . absint($logo_width) . 'px;
        max-width: ' . 100 . '%;
    }';

    wp_add_inline_style('holistic-coach', $custom_css);
}
add_action('wp_enqueue_scripts', 'holistic_coach_dynamic_css', 99);

require get_stylesheet_directory() . '/testimonial.php';

function holistic_coach_default_icon_text_size()
{
    return 'blossom-coach-blog';
}
add_filter('bttk_icon_img_size', 'holistic_coach_default_icon_text_size');

/**
 * Filter for Testimonial widget
 */
function holistic_coach_testimonial_widget_filter($html, $args, $instance)
{

    $name        = !empty($instance['name']) ? $instance['name'] : '';
    $designation = !empty($instance['designation']) ? $instance['designation'] : '';
    $testimonial = !empty($instance['testimonial']) ? $instance['testimonial'] : '';
    $image       = !empty($instance['image']) ? $instance['image'] : '';

    if ($image) {
        /** Added to work for demo testimonial compatible */
        $attachment_id = $image;
        if (!filter_var($image, FILTER_VALIDATE_URL) === false) {
            $attachment_id = bttk_get_attachment_id($image);
        }

        $icon_img_size = apply_filters('bttk_testimonial_icon_img_size', 'thumbnail');
    }

    ob_start();
?>

    <div class="bttk-testimonial-holder">
        <div class="bttk-testimonial-inner-holder">

            <div class="testimonial-icon">
                <span>
                    <svg width="35" height="27" viewBox="0 0 35 27" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M0.502079 20.1017L0.544792 20.3887L0.589207 20.3784C0.892765 21.798 1.59205 23.1026 2.60616 24.1413C3.62028 25.18 4.90776 25.9103 6.31964 26.2478C7.73153 26.5852 9.21011 26.516 10.5843 26.0482C11.9585 25.5803 13.1722 24.733 14.0848 23.6041C14.9975 22.4752 15.5719 21.111 15.7416 19.6693C15.9112 18.2276 15.6692 16.7673 15.0435 15.4574C14.4178 14.1475 13.4341 13.0416 12.206 12.2675C10.9779 11.4934 9.55582 11.0829 8.10416 11.0834C7.72321 11.0834 7.35762 11.1415 6.99375 11.1944C7.11162 10.7981 7.23291 10.3949 7.42766 10.0327C7.62242 9.50658 7.9265 9.05046 8.22887 8.59092C8.48171 8.09379 8.92758 7.75725 9.25558 7.33187C9.59896 6.91846 10.067 6.64342 10.4377 6.30004C10.8016 5.94129 11.2782 5.76192 11.6575 5.50908C12.0538 5.28187 12.3989 5.03075 12.7679 4.91116L13.6887 4.53192L14.4985 4.19537L13.6716 0.882914L12.6517 1.12892C12.3255 1.21092 11.9274 1.30658 11.4747 1.42104C11.0117 1.50646 10.518 1.7405 9.96795 1.95404C9.42641 2.19833 8.79604 2.36062 8.21179 2.75183C7.62412 3.12425 6.94592 3.43517 6.348 3.934C5.76887 4.44821 5.07017 4.89408 4.55425 5.54667C3.9905 6.15825 3.43358 6.80058 3.00137 7.53175C2.50083 8.22875 2.16087 8.99408 1.80212 9.75087C1.47754 10.5077 1.21616 11.2815 1.00262 12.0332C0.597748 13.54 0.416664 14.9715 0.346622 16.1964C0.28854 17.423 0.322704 18.4429 0.394455 19.1809C0.418461 19.4891 0.454365 19.7962 0.502079 20.1017ZM19.2937 20.1017L19.3365 20.3887L19.3809 20.3784C19.6844 21.798 20.3837 23.1026 21.3978 24.1413C22.4119 25.18 23.6994 25.9103 25.1113 26.2478C26.5232 26.5852 28.0018 26.516 29.376 26.0482C30.7502 25.5803 31.9638 24.733 32.8765 23.6041C33.7892 22.4752 34.3636 21.111 34.5332 19.6693C34.7029 18.2276 34.4609 16.7673 33.8352 15.4574C33.2095 14.1475 32.2257 13.0416 30.9977 12.2675C29.7696 11.4934 28.3475 11.0829 26.8958 11.0834C26.5149 11.0834 26.1493 11.1415 25.7854 11.1944C25.9033 10.7981 26.0246 10.3949 26.2193 10.0327C26.4141 9.50658 26.7182 9.05046 27.0205 8.59092C27.2734 8.09379 27.7192 7.75725 28.0472 7.33187C28.3906 6.91846 28.8587 6.64342 29.2294 6.30004C29.5933 5.94129 30.0699 5.76192 30.4492 5.50908C30.8455 5.28187 31.1906 5.03075 31.5596 4.91116L32.4804 4.53192C32.9946 4.32179 33.2884 4.19879 33.2884 4.19879L32.4616 0.886332L31.4417 1.13233C31.1154 1.21433 30.7174 1.31 30.2647 1.42446C29.8017 1.50987 29.308 1.74392 28.7579 1.95746C28.2164 2.20175 27.586 2.36404 27.0017 2.75525C26.4141 3.12766 25.7359 3.43858 25.138 3.93741C24.5588 4.45162 23.8601 4.8975 23.3442 5.55008C22.7805 6.16166 22.2235 6.804 21.7913 7.53517C21.2908 8.23217 20.9508 8.9975 20.5921 9.75429C20.2675 10.5111 20.0061 11.285 19.7926 12.0366C19.3877 13.5434 19.2066 14.975 19.1366 16.1998C19.0785 17.4264 19.1127 18.4463 19.1844 19.1843C19.2099 19.4913 19.2464 19.7973 19.2937 20.1017Z" fill="white" />
                    </svg>
                </span>

            </div>
            <div class="text-holder">
                <?php if ($testimonial) echo '<div class="testimonial-content">' . wpautop(wp_kses_post($testimonial)) . '</div>'; ?>
            </div>
            <div class="testimonial-meta">
                <?php if ($image) { ?>
                    <div class="img-holder">
                        <?php echo wp_get_attachment_image($attachment_id, $icon_img_size, false, array('alt' => esc_attr($name))); ?>
                    </div>
                <?php } ?>
                <div class="user-detail">
                    <?php
                    if ($name) echo '<span class="name">' . esc_html($name) . '</span>';
                    if (isset($designation) && $designation != '') {
                        echo '<span class="designation">' . esc_html($designation) . '</span>';
                    }
                    ?>
                </div>
            </div>
        </div>
    </div>
<?php
    $html = ob_get_clean();
    return $html;
}
add_filter('blossom_testimonial_widget_filter', 'holistic_coach_testimonial_widget_filter', 10, 3);
