<?php
/**
 * Testimonial Section
 *
 * @package Blossom_Coach
 */

function blossom_coach_customize_register_frontpage_testimonial( $wp_customize ){

    /** Testimonial Section */
    $wp_customize->add_section(
        'testimonial',
        array(
            'title'    => __( 'Testimonial Section', 'holistic-coach' ),
            'priority' => 30,
            'panel'    => 'frontpage_settings',
        )
    );
    
    /** Testimonial Title  */
    $wp_customize->add_setting(
        'testimonial_title',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         => 'postMessage',
        )
    );
    
    $wp_customize->add_control(
        'testimonial_title',
        array(
            'label'           => __( 'Testimonial Section Title', 'holistic-coach' ),
            'description'     => __( 'Add title for testimonial section.', 'holistic-coach' ),
            'section'         => 'testimonial',
            'priority'        => -1
        )
    );

    $wp_customize->selective_refresh->add_partial( 'testimonial_title', array(
        'selector' => '.testimonial-section .wrapper h2.section-title',
        'render_callback' => 'blossom_coach_get_testimonial_title',
    ) );

    /** Testimonial Content  */
    $wp_customize->add_setting(
        'testimonial_content',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses_post',
            'transport'         => 'postMessage',
        )
    );
    
    $wp_customize->add_control(
        'testimonial_content',
        array(
            'label'           => __( 'Testimonial Section Description', 'holistic-coach' ),
            'description'     => __( 'Add description for testimonial section.', 'holistic-coach' ),
            'section'         => 'testimonial',
            'type'            => 'textarea',
            'priority'        => -1
        )
    );

    $wp_customize->selective_refresh->add_partial( 'testimonial_content', array(
        'selector' => '.testimonial-section .wrapper .section-desc',
        'render_callback' => 'blossom_coach_get_testimonial_content',
    ) );

    $wp_customize->add_setting(
        'testimonial_note_text',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses_post' 
        )
    );
    
    $wp_customize->add_control(
        new Blossom_Coach_Note_Control( 
            $wp_customize,
            'testimonial_note_text',
            array(
                'section'     => 'testimonial',
                'description' => __( '<hr/>Add "Blossom: Testimonial" widget for testimonial section.', 'holistic-coach' ),
                'priority'    => -1
            )
        )
    );

    $testimonial_section = $wp_customize->get_section( 'sidebar-widgets-testimonial' );
    if ( ! empty( $testimonial_section ) ) {

        $testimonial_section->panel     = 'frontpage_settings';
        $testimonial_section->priority  = 30;
        $wp_customize->get_control( 'testimonial_note_text' )->section = 'sidebar-widgets-testimonial';
        $wp_customize->get_control( 'testimonial_title' )->section = 'sidebar-widgets-testimonial';
        $wp_customize->get_control( 'testimonial_content' )->section = 'sidebar-widgets-testimonial';
    }  
    
    /** Testimonial Section Ends */  

}
add_action( 'customize_register', 'blossom_coach_customize_register_frontpage_testimonial', 999 );

if( ! function_exists( 'blossom_coach_get_testimonial_title' ) ) :
/**
 * Display Testimonial Title
*/
function blossom_coach_get_testimonial_title(){
    return esc_html( get_theme_mod( 'testimonial_title' ) );
}
endif;

if( ! function_exists( 'blossom_coach_get_testimonial_content' ) ) :
/**
 * Display Testimonial Content
*/
function blossom_coach_get_testimonial_content(){
    return wpautop( wp_kses_post( get_theme_mod( 'testimonial_content' ) ) );
}
endif;